aboutsummaryrefslogtreecommitdiffstats
path: root/lib/rdoc/parser/simple.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/rdoc/parser/simple.rb')
-rw-r--r--lib/rdoc/parser/simple.rb5
1 files changed, 2 insertions, 3 deletions
diff --git a/lib/rdoc/parser/simple.rb b/lib/rdoc/parser/simple.rb
index cdfe686718..9072667f89 100644
--- a/lib/rdoc/parser/simple.rb
+++ b/lib/rdoc/parser/simple.rb
@@ -1,5 +1,3 @@
-require 'rdoc/parser'
-
##
# Parse a non-source file. We basically take the whole thing as one big
# comment. If the first character in the file is '#', we strip leading pound
@@ -23,10 +21,11 @@ class RDoc::Parser::Simple < RDoc::Parser
end
##
# Extract the file contents and attach them to the toplevel as a comment
def scan
@top_level.comment = remove_private_comments(@content)
+ @top_level.parser = self.class
@top_level
end
@@ -23,10 +21,11 @@ class RDoc::Parser::Simple < RDoc::Parser
end
##
- # Extract the file contents and attach them to the toplevel as a comment
+ # Extract the file contents and attach them to the TopLevel as a comment
def scan